summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorAdam <Adam@anope.org>2015-01-28 22:57:15 -0500
committerAdam <Adam@anope.org>2015-01-28 22:57:15 -0500
commit845ca576b4c5a94f0a3ec12a4dd524a7d017155e (patch)
tree2636bc0ccdf94f957a955277dd89155de49360b6 /include
parent2264a206d262f07f6c6d91df867383d6413e0c3f (diff)
More properly track topic change sources and allow users with access to change topics through topiclock
Diffstat (limited to 'include')
-rw-r--r--include/channels.h2
-rw-r--r--include/modules.h5
2 files changed, 4 insertions, 3 deletions
diff --git a/include/channels.h b/include/channels.h
index 9bc6c27c6..80459d357 100644
--- a/include/channels.h
+++ b/include/channels.h
@@ -258,7 +258,7 @@ class CoreExport Channel : public Base, public Extensible
* @param newtopic The new topic
* @param ts The time the new topic is being set
*/
- void ChangeTopicInternal(const Anope::string &user, const Anope::string &newtopic, time_t ts = Anope::CurTime);
+ void ChangeTopicInternal(User *u, const Anope::string &user, const Anope::string &newtopic, time_t ts = Anope::CurTime);
/** Update the topic of the channel, and reset it if topiclock etc says to
* @param user The user setting the topic
diff --git a/include/modules.h b/include/modules.h
index 0569fd33f..5ea35c888 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -474,11 +474,12 @@ class CoreExport Module : public Extensible
virtual void OnJoinChannel(User *u, Channel *c) { throw NotImplementedException(); }
/** Called when a new topic is set
+ * @param source The user changing the topic, if any
* @param c The channel
* @param setter The user who set the new topic
* @param topic The new topic
*/
- virtual void OnTopicUpdated(Channel *c, const Anope::string &user, const Anope::string &topic) { throw NotImplementedException(); }
+ virtual void OnTopicUpdated(User *source, Channel *c, const Anope::string &user, const Anope::string &topic) { throw NotImplementedException(); }
/** Called before a channel expires
* @param ci The channel
@@ -474,11 +474,12 @@ class CoreExport Module : public Extensible
* @param c The channel
- * @param setter The user who set the new topic
+ * @param setter The user who set the new topic, if there is no source
* @param topic The new topic
*/